@@ -59,10 +59,12 @@ import org.uberfire.workbench.model.menu.Menus;
  * This is the default rule editor widget (just text editor based).
  */
 @Dependent
-@WorkbenchEditor(identifier = "DRLEditor", supportedTypes = {DRLResourceType.class, DSLRResourceType.class})
+@WorkbenchEditor(identifier = DRLEditorPresenter.EDITOR_ID, supportedTypes = {DRLResourceType.class, DSLRResourceType.class})
 public class DRLEditorPresenter
         extends KieEditor<String> {
 
+    public static final String EDITOR_ID = "DRLEditor";
+
     @Inject
     protected Caller<DRLTextEditorService> drlTextEditorService;
 
@@ -193,9 +195,16 @@ public class DRLEditorPresenter
                                                                                        commitMessage);
     }
 
+    @Override
+    protected String getEditorIdentifier() {
+        return EDITOR_ID;
+    }
+
     @OnClose
+    @Override
     public void onClose() {
         versionRecordManager.clear();
+        super.onClose();
     }
 
     @OnMayClose
