@@ -16,7 +16,6 @@
 
 package org.drools.workbench.screens.dsltext.client.editor;
 
-import java.util.List;
 import java.util.function.Supplier;
 
 import javax.enterprise.context.Dependent;
@@ -28,11 +27,9 @@ import org.drools.workbench.screens.dsltext.client.type.DSLResourceType;
 import org.drools.workbench.screens.dsltext.model.DSLTextEditorContent;
 import org.drools.workbench.screens.dsltext.service.DSLTextEditorService;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
-import org.guvnor.common.services.shared.validation.model.ValidationMessage;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.common.client.api.RemoteCallback;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
-import org.kie.workbench.common.widgets.client.resources.i18n.CommonConstants;
 import org.kie.workbench.common.widgets.metadata.client.KieEditor;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.client.annotations.WorkbenchEditor;
@@ -41,6 +38,7 @@ import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartTitleDecoration;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
+import org.uberfire.ext.widgets.common.client.callbacks.CommandErrorCallback;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnMayClose;
@@ -54,18 +52,20 @@ import org.uberfire.workbench.model.menu.Menus;
  * DSL Editor Presenter.
  */
 @Dependent
-@WorkbenchEditor(identifier = "DSLEditor", supportedTypes = { DSLResourceType.class })
+@WorkbenchEditor(identifier = DSLEditorPresenter.EDITOR_ID, supportedTypes = {DSLResourceType.class})
 public class DSLEditorPresenter
         extends KieEditor<String> {
 
+    public static final String EDITOR_ID = "DSLEditor";
+
     @Inject
-    private Caller<DSLTextEditorService> dslTextEditorService;
+    protected Caller<DSLTextEditorService> dslTextEditorService;
 
     @Inject
     private Event<NotificationEvent> notification;
 
     @Inject
-    private ValidationPopup validationPopup;
+    protected ValidationPopup validationPopup;
 
     private DSLEditorView view;
 
@@ -73,23 +73,23 @@ public class DSLEditorPresenter
     private DSLResourceType type;
 
     @Inject
-    public DSLEditorPresenter( final DSLEditorView baseView ) {
-        super( baseView );
+    public DSLEditorPresenter(final DSLEditorView baseView) {
+        super(baseView);
         view = baseView;
     }
 
     @OnStartup
-    public void onStartup( final ObservablePath path,
-                           final PlaceRequest place ) {
-        this.init( path,
-                   place,
-                   type );
+    public void onStartup(final ObservablePath path,
+                          final PlaceRequest place) {
+        this.init(path,
+                  place,
+                  type);
     }
 
     protected void loadContent() {
         view.showLoading();
-        dslTextEditorService.call( getModelSuccessCallback(),
-                                   getNoSuchFileExceptionErrorCallback() ).loadContent( versionRecordManager.getCurrentPath() );
+        dslTextEditorService.call(getModelSuccessCallback(),
+                                  getNoSuchFileExceptionErrorCallback()).loadContent(versionRecordManager.getCurrentPath());
     }
 
     @Override
@@ -106,62 +106,57 @@ public class DSLEditorPresenter
         return new RemoteCallback<DSLTextEditorContent>() {
 
             @Override
-            public void callback( final DSLTextEditorContent content ) {
+            public void callback(final DSLTextEditorContent content) {
                 //Path is set to null when the Editor is closed (which can happen before async calls complete).
-                if ( versionRecordManager.getCurrentPath() == null ) {
+                if (versionRecordManager.getCurrentPath() == null) {
                     return;
                 }
 
-                resetEditorPages( content.getOverview() );
+                resetEditorPages(content.getOverview());
 
-                view.setContent( content.getModel() );
-                view.setReadOnly( isReadOnly );
+                view.setContent(content.getModel());
+                view.setReadOnly(isReadOnly);
                 view.hideBusyIndicator();
 
                 // We need to get the hash from the widget.
                 // Widget changes the String somehow -> hash changes, even though the string is the same.
-                createOriginalHash( view.getContent() );
-            }
-        };
-    }
-
-    protected Command onValidate() {
-        return new Command() {
-            @Override
-            public void execute() {
-                dslTextEditorService.call( new RemoteCallback<List<ValidationMessage>>() {
-                    @Override
-                    public void callback( final List<ValidationMessage> results ) {
-                        if ( results == null || results.isEmpty() ) {
-                            notification.fire( new NotificationEvent( CommonConstants.INSTANCE.ItemValidatedSuccessfully(),
-                                                                      NotificationEvent.NotificationType.SUCCESS ) );
-                        } else {
-                            validationPopup.showMessages( results );
-                        }
-                    }
-                } ).validate( versionRecordManager.getCurrentPath(),
-                              view.getContent() );
+                createOriginalHash(view.getContent());
             }
         };
     }
 
     @Override
-    protected void save( String commitMessage ) {
-        dslTextEditorService.call( getSaveSuccessCallback( view.getContent().hashCode() ),
-                                   new HasBusyIndicatorDefaultErrorCallback( view ) ).save( versionRecordManager.getCurrentPath(),
-                                                                                            view.getContent(),
-                                                                                            metadata,
-                                                                                            commitMessage );
+    protected void onValidate(final Command finished) {
+        dslTextEditorService.call(
+                validationPopup.getValidationCallback(finished),
+                new CommandErrorCallback(finished)).validate(versionRecordManager.getCurrentPath(),
+                                                             view.getContent());
+    }
+
+    @Override
+    protected void save(String commitMessage) {
+        dslTextEditorService.call(getSaveSuccessCallback(view.getContent().hashCode()),
+                                  new HasBusyIndicatorDefaultErrorCallback(view)).save(versionRecordManager.getCurrentPath(),
+                                                                                       view.getContent(),
+                                                                                       metadata,
+                                                                                       commitMessage);
+    }
+
+    @Override
+    protected String getEditorIdentifier() {
+        return EDITOR_ID;
     }
 
     @OnClose
+    @Override
     public void onClose() {
         this.versionRecordManager.clear();
+        super.onClose();
     }
 
     @OnMayClose
     public boolean mayClose() {
-        return super.mayClose( view.getContent() );
+        return super.mayClose(view.getContent());
     }
 
     @WorkbenchPartTitleDecoration
@@ -183,5 +178,4 @@ public class DSLEditorPresenter
     public Menus getMenus() {
         return menus;
     }
-
 }
