@@ -49,6 +49,7 @@ import org.jboss.errai.common.client.api.RemoteCallback;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
+import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.annotations.WorkbenchEditor;
@@ -56,8 +57,10 @@ import org.uberfire.client.annotations.WorkbenchMenu;
 import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.callbacks.Callback;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.UpdatedLockStatusEvent;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
 import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.lifecycle.OnClose;
 import org.uberfire.lifecycle.OnFocus;
@@ -82,6 +85,8 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
     @Inject
     public GuidedDecisionTableEditorPresenter(final View view,
                                               final Caller<GuidedDecisionTableEditorService> service,
+                                              final AuthoringWorkbenchDocks docks,
+                                              final PerspectiveManager perspectiveManager,
                                               final Event<NotificationEvent> notification,
                                               final Event<DecisionTableSelectedEvent> decisionTableSelectedEvent,
                                               final ValidationPopup validationPopup,
@@ -95,9 +100,12 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
                                               final PlaceManager placeManager,
                                               final ColumnsPage columnsPage,
                                               final SaveAndRenameCommandBuilder<GuidedDecisionTable52, Metadata> saveAndRenameCommandBuilder,
-                                              final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder) {
+                                              final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder,
+                                              final DownloadMenuItem downloadMenuItem) {
         super(view,
               service,
+              docks,
+              perspectiveManager,
               notification,
               decisionTableSelectedEvent,
               validationPopup,
@@ -110,7 +118,8 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
               beanManager,
               placeManager,
               columnsPage,
-              alertsButtonMenuItemBuilder);
+              alertsButtonMenuItemBuilder,
+              downloadMenuItem);
 
         this.saveAndRenameCommandBuilder = saveAndRenameCommandBuilder;
     }
@@ -220,15 +229,17 @@ public class GuidedDecisionTableEditorPresenter extends BaseGuidedDecisionTableE
                                assetUpdateValidator);
         }
 
-        this.menus = getFileMenuBuilder()
+        final FileMenuBuilder fileMenuBuilder = getFileMenuBuilder()
                 .addValidate(() -> onValidate(getActiveDocument()))
                 .addNewTopLevelMenu(getEditMenuItem())
                 .addNewTopLevelMenu(getViewMenuItem())
                 .addNewTopLevelMenu(getInsertMenuItem())
                 .addNewTopLevelMenu(getRadarMenuItem())
                 .addNewTopLevelMenu(getVersionManagerMenuItem())
-                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build())
-                .build();
+                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+        addDownloadMenuItem(fileMenuBuilder);
+
+        this.menus = fileMenuBuilder.build();
     }
 
     protected Command getSaveAndRenameCommand() {
