@@ -63,9 +63,11 @@ import org.kie.soup.project.datamodel.imports.Imports;
 import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.widgets.client.callbacks.CommandDrivenErrorCallback;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
+import org.kie.workbench.common.widgets.client.menu.FileMenuBuilder;
 import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup;
 import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
 import org.uberfire.client.annotations.WorkbenchEditor;
@@ -75,10 +77,12 @@ import org.uberfire.client.annotations.WorkbenchPartView;
 import org.uberfire.client.callbacks.Callback;
 import org.uberfire.client.mvp.LockManager;
 import org.uberfire.client.mvp.LockTarget;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.mvp.SaveInProgressEvent;
 import org.uberfire.client.mvp.UpdatedLockStatusEvent;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
 import org.uberfire.ext.editor.commons.client.menu.MenuItems;
 import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.client.resources.i18n.CommonConstants;
@@ -128,6 +132,8 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
     @Inject
     public GuidedDecisionTableGraphEditorPresenter(final View view,
                                                    final Caller<GuidedDecisionTableEditorService> service,
+                                                   final AuthoringWorkbenchDocks docks,
+                                                   final PerspectiveManager perspectiveManager,
                                                    final Caller<GuidedDecisionTableGraphEditorService> graphService,
                                                    final Caller<KieModuleService> moduleService,
                                                    final Caller<GuidedDecisionTableGraphSaveAndRenameService> graphSaveAndRenameService,
@@ -147,9 +153,12 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                                                    final LockManager lockManager,
                                                    final ColumnsPage columnsPage,
                                                    final SaveAndRenameCommandBuilder<List<GuidedDecisionTableEditorContent>, Metadata> saveAndRenameCommandBuilder,
-                                                   final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder) {
+                                                   final AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder,
+                                                   final DownloadMenuItem downloadMenuItem) {
         super(view,
               service,
+              docks,
+              perspectiveManager,
               notification,
               decisionTableSelectedEvent,
               validationPopup,
@@ -162,7 +171,8 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
               beanManager,
               placeManager,
               columnsPage,
-              alertsButtonMenuItemBuilder);
+              alertsButtonMenuItemBuilder,
+              downloadMenuItem);
         this.graphService = graphService;
         this.moduleService = moduleService;
         this.saveInProgressEvent = saveInProgressEvent;
@@ -335,20 +345,14 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
 
     private boolean doMayCloseGraph(final Integer originalHashCode,
                                     final Integer currentHashCode) {
-        if (this.isDirty(originalHashCode,
-                         currentHashCode) || overviewWidget.isDirty()) {
-            return this.editorView.confirmClose();
-        }
-        return true;
+        return !this.isDirty(originalHashCode,
+                             currentHashCode) && !overviewWidget.isDirty();
     }
 
     private boolean doMayCloseDocument(final Integer originalHashCode,
                                        final Integer currentHashCode) {
-        if (this.isDirty(originalHashCode,
-                         currentHashCode)) {
-            return this.editorView.confirmClose();
-        }
-        return true;
+        return !this.isDirty(originalHashCode,
+                             currentHashCode);
     }
 
     GuidedDecisionTableEditorGraphModel buildModelFromEditor() {
@@ -399,7 +403,7 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                                assetUpdateValidator);
         }
 
-        this.menus = fileMenuBuilder
+        final FileMenuBuilder fileMenuBuilder = this.fileMenuBuilder
                 .addValidate(() -> onValidate(getActiveDocument()))
                 .addNewTopLevelMenu(getEditMenuItem())
                 .addNewTopLevelMenu(getViewMenuItem())
@@ -407,8 +411,10 @@ public class GuidedDecisionTableGraphEditorPresenter extends BaseGuidedDecisionT
                 .addNewTopLevelMenu(getRadarMenuItem())
                 .addNewTopLevelMenu(getRegisteredDocumentsMenuItem())
                 .addNewTopLevelMenu(getVersionManagerMenuItem())
-                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build())
-                .build();
+                .addNewTopLevelMenu(alertsButtonMenuItemBuilder.build());
+        addDownloadMenuItem(fileMenuBuilder);
+
+        this.menus = fileMenuBuilder.build();
     }
 
     protected Command getSaveAndRenameCommand() {
