@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -18,6 +18,8 @@ package org.drools.workbench.screens.guided.dtable.client.editor;
 
 import java.lang.reflect.Field;
 import java.util.Collections;
+import java.util.Optional;
+
 import javax.enterprise.event.Event;
 
 import org.drools.workbench.models.datamodel.workitems.PortableWorkDefinition;
@@ -26,16 +28,18 @@ import org.drools.workbench.screens.guided.dtable.client.editor.menu.EditMenuBui
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.InsertMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.RadarMenuBuilder;
 import org.drools.workbench.screens.guided.dtable.client.editor.menu.ViewMenuBuilder;
+import org.drools.workbench.screens.guided.dtable.client.editor.page.ColumnsPage;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableModellerView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTableView;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.events.cdi.DecisionTableSelectedEvent;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorContent;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableEditorService;
+import org.guvnor.common.services.project.client.context.WorkspaceProjectContext;
 import org.guvnor.common.services.project.client.security.ProjectController;
-import org.guvnor.common.services.project.context.ProjectContext;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
+import org.guvnor.messageconsole.client.console.widget.button.AlertsButtonMenuItemBuilder;
 import org.jboss.errai.common.client.api.Caller;
 import org.jboss.errai.ioc.client.container.SyncBeanManager;
 import org.junit.Before;
@@ -49,15 +53,20 @@ import org.kie.workbench.common.widgets.client.popups.validation.ValidationPopup
 import org.kie.workbench.common.widgets.configresource.client.widget.bound.ImportsWidgetPresenter;
 import org.kie.workbench.common.widgets.metadata.client.KieMultipleDocumentEditorWrapperView;
 import org.kie.workbench.common.widgets.metadata.client.menu.RegisteredDocumentsMenuBuilder;
+import org.kie.workbench.common.widgets.metadata.client.validation.AssetUpdateValidator;
 import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
 import org.mockito.Spy;
 import org.uberfire.backend.vfs.ObservablePath;
 import org.uberfire.backend.vfs.Path;
+import org.uberfire.client.mvp.PerspectiveActivity;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.PlaceManager;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
+import org.uberfire.client.workbench.widgets.multipage.MultiPageEditor;
 import org.uberfire.ext.editor.commons.client.file.popups.CopyPopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.DeletePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.file.popups.RenamePopUpPresenter;
@@ -65,6 +74,7 @@ import org.uberfire.ext.editor.commons.client.file.popups.SavePopUpPresenter;
 import org.uberfire.ext.editor.commons.client.history.VersionRecordManager;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilderImpl;
+import org.uberfire.ext.editor.commons.client.menu.DownloadMenuItem;
 import org.uberfire.ext.editor.commons.client.menu.RestoreVersionCommandProvider;
 import org.uberfire.ext.editor.commons.client.validation.DefaultFileNameValidator;
 import org.uberfire.ext.editor.commons.version.VersionService;
@@ -78,9 +88,13 @@ import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
-import static org.junit.Assert.*;
+import static org.junit.Assert.fail;
 import static org.mockito.Matchers.any;
-import static org.mockito.Mockito.*;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.when;
 
 public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedDecisionTableEditorPresenter> {
 
@@ -89,6 +103,13 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
 
     @Mock
     protected GuidedDecisionTableEditorService dtService;
+
+    @Mock
+    protected AuthoringWorkbenchDocks docks;
+
+    @Mock
+    protected PerspectiveManager perspectiveManager;
+
     protected Caller<GuidedDecisionTableEditorService> dtServiceCaller;
 
     protected Event<NotificationEvent> notification = spy(new EventSourceMock<NotificationEvent>() {
@@ -172,7 +193,7 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
     protected EventSourceMock<ChangeTitleWidgetEvent> changeTitleEvent;
 
     @Mock
-    protected ProjectContext workbenchContext;
+    protected WorkspaceProjectContext workbenchContext;
 
     @Mock
     protected VersionRecordManager versionRecordManager;
@@ -196,6 +217,12 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
     @Mock
     protected BusyIndicatorView busyIndicatorView;
 
+    @Mock
+    protected DownloadMenuItem downloadMenuItem;
+
+    @Mock
+    protected MenuItem downloadMenuItemButton;
+
     @Spy
     protected RestoreVersionCommandProvider restoreVersionCommandProvider = getRestoreVersionCommandProvider();
 
@@ -208,21 +235,39 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
     @Mock
     protected DefaultFileNameValidator fileNameValidator;
 
+    @Mock
+    protected AssetUpdateValidator assetUpdateValidator;
+
     @Mock
     protected SyncBeanManager beanManager;
 
     @Mock
     protected PlaceManager placeManager;
 
+    @Mock
+    protected ColumnsPage columnsPage;
+
+    @Mock
+    protected MultiPageEditor multiPageEditor;
+
     @Mock
     protected ProjectController projectController;
 
+    @Mock
+    protected PerspectiveActivity currentPerspective;
+
     @Captor
     protected ArgumentCaptor<DecisionTableSelectedEvent> dtSelectedEventCaptor;
 
     @Rule
     public ExpectedException exception = ExpectedException.none();
 
+    @Mock
+    protected AlertsButtonMenuItemBuilder alertsButtonMenuItemBuilder;
+
+    @Mock
+    protected MenuItem alertsButtonMenuItem;
+
     protected P presenter;
 
     @Before
@@ -243,6 +288,7 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
         wrapped.setRegisteredDocumentsMenuBuilder(registeredDocumentsMenuBuilder);
         wrapped.setFileMenuBuilder(fileMenuBuilder);
         wrapped.setFileNameValidator(fileNameValidator);
+        wrapped.setAssetUpdateValidator(assetUpdateValidator);
 
         this.presenter = spy(wrapped);
 
@@ -255,6 +301,15 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
         when(insertMenuBuilder.build()).thenReturn(insertMenuItem);
         when(radarMenuBuilder.build()).thenReturn(radarMenuItem);
         when(registeredDocumentsMenuBuilder.build()).thenReturn(registeredDocumentsMenuItem);
+        when(presenter.getKieEditorWrapperMultiPage()).thenReturn(multiPageEditor);
+
+        when(workbenchContext.getActiveOrganizationalUnit()).thenReturn(Optional.empty());
+        when(workbenchContext.getActiveWorkspaceProject()).thenReturn(Optional.empty());
+        when(downloadMenuItem.build(any())).thenReturn(downloadMenuItemButton);
+
+        doReturn(alertsButtonMenuItem).when(alertsButtonMenuItemBuilder).build();
+
+        doReturn(currentPerspective).when(perspectiveManager).getCurrentPerspective();
 
         presenter.init();
         presenter.setupMenuBar();
@@ -302,6 +357,11 @@ public abstract class BaseGuidedDecisionTablePresenterTest<P extends BaseGuidedD
             public int hashCode() {
                 return hashCode;
             }
+
+            @Override
+            public boolean equals(Object o) {
+                return super.equals(o);
+            }
         };
         final Overview overview = mock(Overview.class);
         final Metadata metadata = mock(Metadata.class);
