@@ -5,7 +5,7 @@
  * you may not use this file except in compliance with the License.
  * You may obtain a copy of the License at
  *
- *       http://www.apache.org/licenses/LICENSE-2.0
+ *     http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -20,14 +20,16 @@ import java.util.ArrayList;
 import java.util.Date;
 import java.util.HashSet;
 import java.util.List;
+import java.util.Optional;
 import java.util.Set;
+import java.util.function.Supplier;
 import java.util.stream.Collectors;
+
 import javax.enterprise.event.Event;
 
 import com.google.gwt.core.client.Scheduler;
 import com.google.gwt.user.client.ui.Widget;
 import com.google.gwtmockito.GwtMockitoTestRunner;
-import org.drools.workbench.models.datamodel.imports.Imports;
 import org.drools.workbench.models.guided.dtable.shared.model.GuidedDecisionTable52;
 import org.drools.workbench.screens.guided.dtable.client.type.GuidedDTableGraphResourceType;
 import org.drools.workbench.screens.guided.dtable.client.widget.table.GuidedDecisionTablePresenter;
@@ -40,7 +42,9 @@ import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEdito
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorGraphModel;
 import org.drools.workbench.screens.guided.dtable.model.GuidedDecisionTableEditorGraphModel.GuidedDecisionTableGraphEntry;
 import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphEditorService;
-import org.guvnor.common.services.project.model.Project;
+import org.drools.workbench.screens.guided.dtable.service.GuidedDecisionTableGraphSaveAndRenameService;
+import org.guvnor.common.services.project.categories.Decision;
+import org.guvnor.common.services.project.model.WorkspaceProject;
 import org.guvnor.common.services.shared.metadata.model.Metadata;
 import org.guvnor.common.services.shared.metadata.model.Overview;
 import org.jboss.errai.common.client.api.Caller;
@@ -48,10 +52,13 @@ import org.jboss.errai.common.client.api.RemoteCallback;
 import org.junit.Before;
 import org.junit.Test;
 import org.junit.runner.RunWith;
-import org.kie.workbench.common.services.shared.project.KieProjectService;
+import org.kie.soup.project.datamodel.imports.Imports;
+import org.kie.workbench.common.services.shared.project.KieModuleService;
 import org.kie.workbench.common.widgets.client.datamodel.AsyncPackageDataModelOracle;
 import org.kie.workbench.common.widgets.client.source.ViewDRLSourceWidget;
 import org.kie.workbench.common.widgets.metadata.client.KieDocument;
+import org.kie.workbench.common.widgets.metadata.client.widget.OverviewWidgetPresenter;
+import org.kie.workbench.common.workbench.client.docks.AuthoringWorkbenchDocks;
 import org.mockito.ArgumentCaptor;
 import org.mockito.Captor;
 import org.mockito.Mock;
@@ -63,11 +70,14 @@ import org.uberfire.backend.vfs.impl.ObservablePathImpl;
 import org.uberfire.client.callbacks.Callback;
 import org.uberfire.client.mvp.LockManager;
 import org.uberfire.client.mvp.LockTarget;
+import org.uberfire.client.mvp.PerspectiveManager;
 import org.uberfire.client.mvp.SaveInProgressEvent;
 import org.uberfire.client.mvp.UpdatedLockStatusEvent;
 import org.uberfire.client.workbench.events.ChangeTitleWidgetEvent;
 import org.uberfire.ext.editor.commons.client.menu.BasicFileMenuBuilder;
+import org.uberfire.ext.editor.commons.client.menu.common.SaveAndRenameCommandBuilder;
 import org.uberfire.ext.editor.commons.client.resources.i18n.CommonConstants;
+import org.uberfire.ext.editor.commons.client.validation.Validator;
 import org.uberfire.ext.editor.commons.version.events.RestoreEvent;
 import org.uberfire.ext.editor.commons.version.impl.PortableVersionRecord;
 import org.uberfire.java.nio.base.version.VersionRecord;
@@ -80,8 +90,24 @@ import org.uberfire.mvp.impl.PathPlaceRequest;
 import org.uberfire.workbench.events.NotificationEvent;
 import org.uberfire.workbench.model.menu.MenuItem;
 
-import static org.junit.Assert.*;
-import static org.mockito.Mockito.*;
+import static org.junit.Assert.assertEquals;
+import static org.junit.Assert.assertFalse;
+import static org.junit.Assert.assertNotNull;
+import static org.junit.Assert.assertNull;
+import static org.junit.Assert.assertTrue;
+import static org.junit.Assert.fail;
+import static org.mockito.Matchers.startsWith;
+import static org.mockito.Mockito.any;
+import static org.mockito.Mockito.doNothing;
+import static org.mockito.Mockito.doReturn;
+import static org.mockito.Mockito.eq;
+import static org.mockito.Mockito.mock;
+import static org.mockito.Mockito.never;
+import static org.mockito.Mockito.reset;
+import static org.mockito.Mockito.spy;
+import static org.mockito.Mockito.times;
+import static org.mockito.Mockito.verify;
+import static org.mockito.Mockito.when;
 
 @RunWith(GwtMockitoTestRunner.class)
 public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecisionTablePresenterTest<GuidedDecisionTableGraphEditorPresenter> {
@@ -97,8 +123,12 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
     private Caller<GuidedDecisionTableGraphEditorService> dtGraphServiceCaller;
 
     @Mock
-    private KieProjectService projectService;
-    private Caller<KieProjectService> projectServiceCaller;
+    private KieModuleService moduleService;
+    private Caller<KieModuleService> moduleServiceCaller;
+
+    @Mock
+    private GuidedDecisionTableGraphSaveAndRenameService graphSaveAndRenameService;
+    private Caller<GuidedDecisionTableGraphSaveAndRenameService> graphSaveAndRenameServiceCaller;
 
     @Mock
     private NewGuidedDecisionTableWizardHelper helper;
@@ -109,6 +139,9 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
     @Mock
     private Path activePackageResourcesPath;
 
+    @Mock
+    private SaveAndRenameCommandBuilder<List<GuidedDecisionTableEditorContent>, Metadata> saveAndRenameCommandBuilder;
+
     @Captor
     private ArgumentCaptor<ParameterizedCommand<KieDocument>> activateDocumentCommandCaptor;
 
@@ -145,6 +178,9 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
     @Captor
     private ArgumentCaptor<RemoteCallback<Path>> onSaveSuccessCallbackCaptor;
 
+    @Mock
+    protected AuthoringWorkbenchDocks docks;
+
     private Event<SaveInProgressEvent> saveInProgressEvent = spy(new EventSourceMock<SaveInProgressEvent>() {
         @Override
         public void fire(final SaveInProgressEvent event) {
@@ -152,16 +188,18 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
         }
     });
 
-    private GuidedDTableGraphResourceType dtGraphResourceType = new GuidedDTableGraphResourceType();
+    private GuidedDTableGraphResourceType dtGraphResourceType = new GuidedDTableGraphResourceType(new Decision());
 
+    @Override
     @Before
     public void setup() {
         this.dtGraphServiceCaller = new CallerMock<>(dtGraphService);
-        this.projectServiceCaller = new CallerMock<>(projectService);
-
+        this.moduleServiceCaller = new CallerMock<>(moduleService);
+        this.graphSaveAndRenameServiceCaller = new CallerMock<>(graphSaveAndRenameService);
         when(view.asWidget()).thenReturn(mock(Widget.class));
-        when(projectService.resolvePackage(any(Path.class))).thenReturn(activePackage);
+        when(moduleService.resolvePackage(any(Path.class))).thenReturn(activePackage);
         when(activePackage.getPackageMainResourcesPath()).thenReturn(activePackageResourcesPath);
+        when(alertsButtonMenuItemBuilder.build()).thenReturn(alertsButtonMenuItem);
 
         super.setup();
     }
@@ -170,8 +208,11 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
     protected GuidedDecisionTableGraphEditorPresenter getPresenter() {
         return new GuidedDecisionTableGraphEditorPresenter(view,
                                                            dtServiceCaller,
+                                                           docks,
+                                                           mock(PerspectiveManager.class),
                                                            dtGraphServiceCaller,
-                                                           projectServiceCaller,
+                                                           moduleServiceCaller,
+                                                           graphSaveAndRenameServiceCaller,
                                                            notification,
                                                            saveInProgressEvent,
                                                            decisionTableSelectedEvent,
@@ -185,12 +226,21 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
                                                            helper,
                                                            beanManager,
                                                            placeManager,
-                                                           lockManager) {
+                                                           lockManager,
+                                                           columnsPage,
+                                                           saveAndRenameCommandBuilder,
+                                                           alertsButtonMenuItemBuilder,
+                                                           downloadMenuItem) {
             {
                 workbenchContext = GuidedDecisionTableGraphEditorPresenterTest.this.workbenchContext;
                 projectController = GuidedDecisionTableGraphEditorPresenterTest.this.projectController;
             }
 
+            @Override
+            protected Command getSaveAndRenameCommand() {
+                return mock(Command.class);
+            }
+
             @Override
             PathPlaceRequest getPathPlaceRequest(final Path path) {
                 //Avoid use of IOC.getBeanManager().lookupBean(..) in PathPlaceRequest for Unit Tests
@@ -303,36 +353,25 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
 
     @Test
     public void testSetupMenuBar() {
-        verify(fileMenuBuilder,
-               times(1)).addSave(any(MenuItem.class));
-        verify(fileMenuBuilder,
-               times(1)).addCopy(any(BasicFileMenuBuilder.PathProvider.class),
-                                 eq(fileNameValidator));
-        verify(fileMenuBuilder,
-               times(1)).addRename(any(BasicFileMenuBuilder.PathProvider.class),
-                                   eq(fileNameValidator));
-        verify(fileMenuBuilder,
-               times(1)).addDelete(any(BasicFileMenuBuilder.PathProvider.class));
-        verify(fileMenuBuilder,
-               times(1)).addValidate(any(Command.class));
-        verify(fileMenuBuilder,
-               times(1)).addNewTopLevelMenu(eq(editMenuItem));
-        verify(fileMenuBuilder,
-               times(1)).addNewTopLevelMenu(eq(viewMenuItem));
-        verify(fileMenuBuilder,
-               times(1)).addNewTopLevelMenu(eq(insertMenuItem));
-        verify(fileMenuBuilder,
-               times(1)).addNewTopLevelMenu(eq(radarMenuItem));
-        verify(fileMenuBuilder,
-               times(1)).addNewTopLevelMenu(eq(versionManagerMenuItem));
-        verify(fileMenuBuilder,
-               times(1)).addNewTopLevelMenu(eq(registeredDocumentsMenuItem));
+        verify(fileMenuBuilder).addSave(any(MenuItem.class));
+        verify(fileMenuBuilder).addCopy(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder).addRename(any(Command.class));
+        verify(fileMenuBuilder).addDelete(any(BasicFileMenuBuilder.PathProvider.class), eq(assetUpdateValidator));
+        verify(fileMenuBuilder).addValidate(any(Command.class));
+        verify(fileMenuBuilder).addNewTopLevelMenu(eq(editMenuItem));
+        verify(fileMenuBuilder).addNewTopLevelMenu(eq(viewMenuItem));
+        verify(fileMenuBuilder).addNewTopLevelMenu(eq(insertMenuItem));
+        verify(fileMenuBuilder).addNewTopLevelMenu(eq(radarMenuItem));
+        verify(fileMenuBuilder).addNewTopLevelMenu(eq(versionManagerMenuItem));
+        verify(fileMenuBuilder).addNewTopLevelMenu(eq(registeredDocumentsMenuItem));
+        verify(fileMenuBuilder).addNewTopLevelMenu(alertsButtonMenuItem);
+        verify(fileMenuBuilder).addNewTopLevelMenu(downloadMenuItemButton);
     }
 
     @Test
     public void testMakeMenuBarWithoutUpdateProjectPermission() {
         reset(fileMenuBuilder);
-        doReturn(mock(Project.class)).when(workbenchContext).getActiveProject();
+        doReturn(Optional.of(mock(WorkspaceProject.class))).when(workbenchContext).getActiveWorkspaceProject();
         doReturn(false).when(projectController).canUpdateProject(any());
 
         presenter.makeMenuBar();
@@ -341,12 +380,15 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
                never()).addSave(any(MenuItem.class));
         verify(fileMenuBuilder,
                never()).addCopy(any(BasicFileMenuBuilder.PathProvider.class),
-                                eq(fileNameValidator));
+                                eq(assetUpdateValidator));
         verify(fileMenuBuilder,
                never()).addRename(any(BasicFileMenuBuilder.PathProvider.class),
-                                  eq(fileNameValidator));
+                                  eq(assetUpdateValidator));
         verify(fileMenuBuilder,
-               never()).addDelete(any(BasicFileMenuBuilder.PathProvider.class));
+               never()).addDelete(any(BasicFileMenuBuilder.PathProvider.class),
+                                  eq(assetUpdateValidator));
+        verify(fileMenuBuilder,
+               times(1)).addNewTopLevelMenu(alertsButtonMenuItem);
     }
 
     @Test
@@ -471,6 +513,37 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
                never()).acquireLock();
     }
 
+    @Test
+    public void testLoadDocumentGraphEmptyModel() throws Exception {
+        final ObservablePath documentPath = mock(ObservablePath.class);
+        final Overview overview = mock(Overview.class);
+        final GuidedDecisionTableEditorGraphModel graphModel = mock(GuidedDecisionTableEditorGraphModel.class);
+        final GuidedDecisionTableEditorGraphContent graphContent = mock(GuidedDecisionTableEditorGraphContent.class);
+
+        when(documentPath.getFileName()).thenReturn("GDT");
+        when(versionRecordManager.getCurrentPath()).thenReturn(documentPath);
+        when(dtGraphService.loadContent(documentPath)).thenReturn(graphContent);
+        when(versionRecordManager.getPathToLatest()).thenReturn(documentPath);
+        when(graphContent.getOverview()).thenReturn(overview);
+        when(graphContent.getModel()).thenReturn(graphModel);
+
+        presenter.loadDocumentGraph(documentPath);
+        verify(view).showLoading();
+        verify(view).hideBusyIndicator();
+        verify(view).refreshTitle(startsWith("GDT"));
+
+        // initialise when no documents
+        verify(editMenuItem).setEnabled(false);
+        verify(viewMenuItem).setEnabled(false);
+        verify(insertMenuItem).setEnabled(false);
+        verify(radarMenuItem).setEnabled(false);
+
+        verify(kieEditorWrapperView).clear();
+        verify(kieEditorWrapperView).addMainEditorPage(view);
+        verify(kieEditorWrapperView).addOverviewPage(eq(overviewWidget), any(com.google.gwt.user.client.Command.class));
+        verify(overviewWidget).setContent(overview, documentPath);
+    }
+
     @Test
     public void checkMayCloseWithCleanDecisionTableGraph() {
         checkMayClose(0,
@@ -641,6 +714,48 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
                                                   times(1)).acquireLock());
     }
 
+    @Test
+    public void testOnDecisionTableSelectedWhenPresenterIsNull() {
+
+        final DecisionTableSelectedEvent event = mock(DecisionTableSelectedEvent.class);
+
+        doReturn(Optional.empty()).when(event).getPresenter();
+        doNothing().when(presenter).initialiseEditorTabsWhenNoDocuments();
+
+        presenter.onDecisionTableSelected(event);
+
+        verify(presenter).initialiseEditorTabsWhenNoDocuments();
+    }
+
+    @Test
+    public void testOnDecisionTableSelectedWhenPresenterIsNotNull() {
+
+        final GuidedDecisionTableView.Presenter dtPresenter = mock(GuidedDecisionTableView.Presenter.class);
+        final Overview overview = mock(Overview.class);
+        final AsyncPackageDataModelOracle oracle = mock(AsyncPackageDataModelOracle.class);
+        final GuidedDecisionTable52 model = new GuidedDecisionTable52();
+        final GuidedDecisionTablePresenter.Access access = new GuidedDecisionTablePresenter.Access();
+        final DecisionTableSelectedEvent event = new DecisionTableSelectedEvent(dtPresenter);
+        final ObservablePath path = mock(ObservablePath.class);
+
+        doNothing().when(presenter).initialiseKieEditorTabs(dtPresenter, overview, oracle, model.getImports(), false);
+        doNothing().when(presenter).initialiseEditorTabsWhenNoDocuments();
+        doReturn(true).when(modeller).isDecisionTableAvailable(dtPresenter);
+        doReturn(Optional.of(dtPresenter)).when(modeller).getActiveDecisionTable();
+        doReturn(overview).when(dtPresenter).getOverview();
+        doReturn(oracle).when(dtPresenter).getDataModelOracle();
+        doReturn(model).when(dtPresenter).getModel();
+        doReturn(access).when(dtPresenter).getAccess();
+        doReturn(path).when(dtPresenter).getLatestPath();
+
+        presenter.registerDocument(dtPresenter);
+        presenter.onDecisionTableSelected(event);
+
+        verify(presenter, never()).initialiseEditorTabsWhenNoDocuments();
+        verify(presenter).addColumnsTab();
+        verify(presenter).enableColumnsTab(dtPresenter);
+    }
+
     private void checkOnDecisionTableSelected(final ParameterizedCommand<PlaceRequest> setup,
                                               final Command assertion) {
         final ObservablePath dtGraphPath = mock(ObservablePath.class);
@@ -1252,6 +1367,8 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
 
     @Test
     public void checkOnUpdatedLockStatusEventWithNullPath() {
+        when(modeller.getActiveDecisionTable()).thenReturn(Optional.empty());
+
         checkOnUpdatedLockStatusEvent(null,
                                       false,
                                       false,
@@ -1261,6 +1378,8 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
 
     @Test
     public void checkOnUpdatedLockStatusEventNotLocked() {
+        when(modeller.getActiveDecisionTable()).thenReturn(Optional.empty());
+
         checkOnUpdatedLockStatusEvent(mock(ObservablePath.class),
                                       false,
                                       false,
@@ -1270,6 +1389,8 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
 
     @Test
     public void checkOnUpdatedLockStatusEventLockedByOtherUser() {
+        when(modeller.getActiveDecisionTable()).thenReturn(Optional.empty());
+
         checkOnUpdatedLockStatusEvent(mock(ObservablePath.class),
                                       true,
                                       false,
@@ -1279,6 +1400,8 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
 
     @Test
     public void checkOnUpdatedLockStatusEventLockedByCurrentUser() {
+        when(modeller.getActiveDecisionTable()).thenReturn(Optional.empty());
+
         checkOnUpdatedLockStatusEvent(mock(ObservablePath.class),
                                       true,
                                       true,
@@ -1286,6 +1409,209 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
                                                          presenter.access.getLock()));
     }
 
+    @Test
+    public void testGetSaveAndRenameCommand() {
+
+        final Command expectedCommand = mock(Command.class);
+        final GuidedDecisionTableGraphEditorPresenter presenter = makePresenter();
+
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addPathSupplier(any());
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addValidator(any(Validator.class));
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addValidator(any(Supplier.class));
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addRenameService(any());
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addMetadataSupplier(any());
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addContentSupplier(any());
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addIsDirtySupplier(any());
+        doReturn(saveAndRenameCommandBuilder).when(saveAndRenameCommandBuilder).addSuccessCallback(any());
+        doReturn(expectedCommand).when(saveAndRenameCommandBuilder).build();
+
+        final Command actualCommand = presenter.getSaveAndRenameCommand();
+
+        assertEquals(expectedCommand, actualCommand);
+    }
+
+    @Test
+    public void testGetMetadataSupplier() {
+
+        final GuidedDecisionTableView.Presenter document = mock(GuidedDecisionTableView.Presenter.class);
+        final Overview overview = mock(Overview.class);
+        final Metadata expectedMetadata = mock(Metadata.class);
+
+        doReturn(document).when(presenter).getActiveDocument();
+        doReturn(overview).when(document).getOverview();
+        doReturn(expectedMetadata).when(overview).getMetadata();
+
+        final Metadata actualMetadata = presenter.getMetadataSupplier().get();
+
+        assertEquals(expectedMetadata, actualMetadata);
+    }
+
+    @Test
+    public void testGetContentSupplier() {
+
+        final GuidedDecisionTableView.Presenter presenter = mock(GuidedDecisionTableView.Presenter.class);
+        final GuidedDecisionTable52 model = mock(GuidedDecisionTable52.class);
+        final Overview overview = mock(Overview.class);
+        final ObservablePath currentPath = mock(ObservablePath.class);
+        final ObservablePath latestPath = mock(ObservablePath.class);
+
+        doReturn(model).when(presenter).getModel();
+        doReturn(overview).when(presenter).getOverview();
+        doReturn(currentPath).when(presenter).getCurrentPath();
+        doReturn(latestPath).when(presenter).getLatestPath();
+        doReturn(asSet(presenter)).when(this.presenter).getAvailableDecisionTables();
+
+        final List<GuidedDecisionTableEditorContent> content = this.presenter.getContentSupplier().get();
+        final GuidedDecisionTableEditorContent firstContent = content.get(0);
+
+        assertEquals(1, content.size());
+
+        assertEquals(model, firstContent.getModel());
+        assertEquals(overview, firstContent.getOverview());
+        assertEquals(currentPath, firstContent.getCurrentPath());
+        assertEquals(latestPath, firstContent.getLatestPath());
+    }
+
+    @Test
+    public void testIsGuidedDecisionTablesDirtyWhenItIsDirty() {
+
+        final GuidedDecisionTableView.Presenter presenter = mock(GuidedDecisionTableView.Presenter.class);
+        final GuidedDecisionTable52 model = mock(GuidedDecisionTable52.class);
+        final Set<GuidedDecisionTableView.Presenter> availableDecisionTables = asSet(presenter);
+        final int currentHash = 456;
+        final int originalHash = 123;
+
+        doReturn(currentHash).when(this.presenter).currentHashCode(presenter);
+        doReturn(originalHash).when(this.presenter).originalHashCode(presenter);
+        doReturn(model).when(presenter).getModel();
+        doReturn(availableDecisionTables).when(this.presenter).getAvailableDecisionTables();
+
+        final boolean isDirty = this.presenter.isGuidedDecisionTablesDirty();
+
+        assertTrue(isDirty);
+    }
+
+    @Test
+    public void testIsGuidedDecisionTablesDirtyWhenItIsNotDirty() {
+
+        final GuidedDecisionTableView.Presenter presenter = mock(GuidedDecisionTableView.Presenter.class);
+        final GuidedDecisionTable52 model = mock(GuidedDecisionTable52.class);
+        final Set<GuidedDecisionTableView.Presenter> availableDecisionTables = asSet(presenter);
+        final int currentHash = 123;
+        final int originalHash = 123;
+
+        doReturn(currentHash).when(this.presenter).currentHashCode(presenter);
+        doReturn(originalHash).when(this.presenter).originalHashCode(presenter);
+        doReturn(model).when(presenter).getModel();
+        doReturn(availableDecisionTables).when(this.presenter).getAvailableDecisionTables();
+
+        final boolean isDirty = this.presenter.isGuidedDecisionTablesDirty();
+
+        assertFalse(isDirty);
+    }
+
+    @Test
+    public void testIsGraphDirtyWhenItIsDirty() {
+
+        presenter.originalGraphHash = 123;
+        doReturn(456).when(presenter).getCurrentHashCode();
+
+        final boolean isDirty = presenter.isGraphDirty();
+
+        assertTrue(isDirty);
+    }
+
+    @Test
+    public void testIsGraphDirtyWhenItIsNotDirty() {
+
+        presenter.originalGraphHash = 123;
+        doReturn(123).when(presenter).getCurrentHashCode();
+
+        final boolean isDirty = presenter.isGraphDirty();
+
+        assertFalse(isDirty);
+    }
+
+    @Test
+    public void testIsOverviewWidgetDirtyWhenItIsDirty() {
+
+        final OverviewWidgetPresenter overviewWidget = mock(OverviewWidgetPresenter.class);
+
+        doReturn(true).when(overviewWidget).isDirty();
+        doReturn(overviewWidget).when(presenter).getOverviewWidget();
+
+        final boolean isDirty = presenter.isOverviewWidgetDirty();
+
+        assertTrue(isDirty);
+    }
+
+    @Test
+    public void testIsOverviewWidgetDirtyWhenItIsNotDirty() {
+
+        final OverviewWidgetPresenter overviewWidget = mock(OverviewWidgetPresenter.class);
+
+        doReturn(false).when(overviewWidget).isDirty();
+        doReturn(overviewWidget).when(presenter).getOverviewWidget();
+
+        final boolean isDirty = presenter.isOverviewWidgetDirty();
+
+        assertFalse(isDirty);
+    }
+
+    @Test
+    public void testGetIsDirtySupplierWhenGuidedDecisionTablesIsDirty() {
+
+        doReturn(true).when(presenter).isGuidedDecisionTablesDirty();
+        doReturn(false).when(presenter).isGraphDirty();
+        doReturn(false).when(presenter).isOverviewWidgetDirty();
+
+        final Supplier<Boolean> isDirtySupplier = presenter.getIsDirtySupplier();
+
+        assertTrue(isDirtySupplier.get());
+    }
+
+    @Test
+    public void testGetIsDirtySupplierWhenGraphIsDirty() {
+
+        doReturn(false).when(presenter).isGuidedDecisionTablesDirty();
+        doReturn(true).when(presenter).isGraphDirty();
+        doReturn(false).when(presenter).isOverviewWidgetDirty();
+
+        final Supplier<Boolean> isDirtySupplier = presenter.getIsDirtySupplier();
+
+        assertTrue(isDirtySupplier.get());
+    }
+
+    @Test
+    public void testGetIsDirtySupplierWhenOverviewWidgetIsDirty() {
+
+        doReturn(false).when(presenter).isGuidedDecisionTablesDirty();
+        doReturn(false).when(presenter).isGraphDirty();
+        doReturn(true).when(presenter).isOverviewWidgetDirty();
+
+        final Supplier<Boolean> isDirtySupplier = presenter.getIsDirtySupplier();
+
+        assertTrue(isDirtySupplier.get());
+    }
+
+    @Test
+    public void testGetIsDirtySupplierWhenItIsNotDirty() {
+
+        doReturn(false).when(presenter).isGuidedDecisionTablesDirty();
+        doReturn(false).when(presenter).isGraphDirty();
+        doReturn(false).when(presenter).isOverviewWidgetDirty();
+
+        final Supplier<Boolean> isDirtySupplier = presenter.getIsDirtySupplier();
+
+        assertFalse(isDirtySupplier.get());
+    }
+
+    private HashSet<GuidedDecisionTableView.Presenter> asSet(final GuidedDecisionTableView.Presenter presenter) {
+        return new HashSet<GuidedDecisionTableView.Presenter>() {{
+            add(presenter);
+        }};
+    }
+
     private void checkOnUpdatedLockStatusEvent(final ObservablePath path,
                                                final boolean locked,
                                                final boolean lockedByCurrentUser,
@@ -1312,14 +1638,48 @@ public class GuidedDecisionTableGraphEditorPresenterTest extends BaseGuidedDecis
             public int hashCode() {
                 return hashCode;
             }
+
+            @Override
+            public boolean equals(Object o) {
+                return super.equals(o);
+            }
         };
         return new GuidedDecisionTableEditorGraphContent(model,
                                                          mock(Overview.class));
     }
 
+    private GuidedDecisionTableGraphEditorPresenter makePresenter() {
+        return new GuidedDecisionTableGraphEditorPresenter(view,
+                                                           dtServiceCaller,
+                                                           docks,
+                                                           mock(PerspectiveManager.class),
+                                                           dtGraphServiceCaller,
+                                                           moduleServiceCaller,
+                                                           graphSaveAndRenameServiceCaller,
+                                                           notification,
+                                                           saveInProgressEvent,
+                                                           decisionTableSelectedEvent,
+                                                           validationPopup,
+                                                           dtGraphResourceType,
+                                                           editMenuBuilder,
+                                                           viewMenuBuilder,
+                                                           insertMenuBuilder,
+                                                           radarMenuBuilder,
+                                                           modeller,
+                                                           helper,
+                                                           beanManager,
+                                                           placeManager,
+                                                           lockManager,
+                                                           columnsPage,
+                                                           saveAndRenameCommandBuilder,
+                                                           alertsButtonMenuItemBuilder,
+                                                           downloadMenuItem);
+    }
+
     private static class OnSaveSetupDataHolder {
 
         private ObservablePath dtGraphPath;
+
         private PlaceRequest dtGraphPlaceRequest;
         private GuidedDecisionTableView.Presenter dtPresenter;
 
