@@ -42,11 +42,13 @@ import org.uberfire.mvp.PlaceRequest;
 import org.uberfire.workbench.model.menu.Menus;
 
 @Dependent
-@WorkbenchEditor(identifier = "ScoreCardXLSEditor", supportedTypes = {ScoreCardXLSResourceType.class})
+@WorkbenchEditor(identifier = ScoreCardXLSEditorPresenter.EDITOR_ID, supportedTypes = {ScoreCardXLSResourceType.class})
 public class ScoreCardXLSEditorPresenter
         extends KieEditor<ScoreCardXLSContent>
         implements ScoreCardXLSEditorView.Presenter {
 
+    public static final String EDITOR_ID = "ScoreCardXLSEditor";
+
     @Inject
     protected Caller<ScoreCardXLSService> scoreCardXLSService;
 
@@ -102,9 +104,16 @@ public class ScoreCardXLSEditorPresenter
                                                              versionRecordManager.getCurrentPath());
     }
 
+    @Override
+    protected String getEditorIdentifier() {
+        return EDITOR_ID;
+    }
+
     @OnClose
+    @Override
     public void onClose() {
         this.versionRecordManager.clear();
+        super.onClose();
     }
 
     @WorkbenchPartTitleDecoration
