@@ -16,12 +16,10 @@
 
 package org.drools.workbench.screens.testscenario.client;
 
-import java.util.Objects;
 import java.util.Optional;
 import java.util.function.Supplier;
 
 import javax.enterprise.event.Event;
-import javax.enterprise.event.Observes;
 import javax.inject.Inject;
 
 import com.google.gwt.user.client.ui.IsWidget;
@@ -54,9 +52,6 @@ import org.uberfire.client.annotations.WorkbenchMenu;
 import org.uberfire.client.annotations.WorkbenchPartTitle;
 import org.uberfire.client.annotations.WorkbenchPartTitleDecoration;
 import org.uberfire.client.annotations.WorkbenchPartView;
-import org.uberfire.client.workbench.events.AbstractPlaceEvent;
-import org.uberfire.client.workbench.events.PlaceGainFocusEvent;
-import org.uberfire.client.workbench.events.PlaceHiddenEvent;
 import org.uberfire.ext.editor.commons.service.support.SupportsSaveAndRename;
 import org.uberfire.ext.widgets.common.client.callbacks.HasBusyIndicatorDefaultErrorCallback;
 import org.uberfire.lifecycle.OnClose;
@@ -78,10 +73,9 @@ public class ScenarioEditorPresenter
     private final AsyncPackageDataModelOracleFactory oracleFactory;
     private final Caller<TestRunnerService> testService;
     private final ImportsWidgetPresenter importsWidget;
-
-    private User user;
     private final SettingsPage settingsPage;
     private final AuditPage auditPage;
+    private User user;
     private Scenario scenario;
     private AsyncPackageDataModelOracle dmo;
 
@@ -133,24 +127,17 @@ public class ScenarioEditorPresenter
                    type);
     }
 
-    public void hideDiagramEditorDocks(@Observes PlaceHiddenEvent event) {
-        if (verifyEventIdentifier(event)) {
-            hideTestPanelEvent.fire(new OnHideTestPanelEvent());
-            testRunnerReportingScreen.reset();
-        }
+    @Override
+    public void hideDocks() {
+        super.hideDocks();
+        hideTestPanelEvent.fire(new OnHideTestPanelEvent());
+        testRunnerReportingScreen.reset();
     }
 
-    public void showDiagramEditorDocks(@Observes PlaceGainFocusEvent event) {
-        if (verifyEventIdentifier(event)) {
-            showTestPanelEvent.fire(new OnShowTestPanelEvent());
-        }
-    }
-
-    private boolean verifyEventIdentifier(AbstractPlaceEvent event) {
-        return (Objects.equals(IDENTIFIER,
-                               event.getPlace().getIdentifier()) &&
-                Objects.equals(place,
-                               event.getPlace()));
+    @Override
+    public void showDocks() {
+        super.showDocks();
+        showTestPanelEvent.fire(new OnShowTestPanelEvent());
     }
 
     protected void loadContent() {
@@ -329,10 +316,17 @@ public class ScenarioEditorPresenter
         return scenario;
     }
 
+    @Override
+    protected String getEditorIdentifier() {
+        return IDENTIFIER;
+    }
+
     @OnClose
+    @Override
     public void onClose() {
         versionRecordManager.clear();
         this.oracleFactory.destroy(dmo);
+        super.onClose();
     }
 
     TestRunFailedErrorCallback getTestRunFailedCallback() {
